.. include:: tutorials/README.rst

.. toctree::
    :maxdepth: 1

    tutorials/t1
    tutorials/t2
    tutorials/t3
    tutorials/t4
    tutorials/t5
    tutorials/t6
    tutorials/t7
    tutorials/t8
    tutorials/t9
